==> dent-0.1.0.tar.gz: lib/src/core/datastore_serializers.dart <==
import 'package:built_collection/built_collection.dart';
import 'package:built_value/iso_8601_date_time_serializer.dart';
import 'package:built_value/serializer.dart';
import 'package:built_value/src/big_int_serializer.dart';
import 'package:built_value/src/bool_serializer.dart';
import 'package:built_value/src/built_list_multimap_serializer.dart';
import 'package:built_value/src/built_list_serializer.dart';
import 'package:built_value/src/built_map_serializer.dart';
import 'package:built_value/src/built_set_multimap_serializer.dart';
import 'package:built_value/src/built_set_serializer.dart';
import 'package:built_value/src/double_serializer.dart';
import 'package:built_value/src/duration_serializer.dart';
import 'package:built_value/src/int64_serializer.dart';
import 'package:built_value/src/int_serializer.dart';
import 'package:built_value/src/json_object_serializer.dart';
import 'package:built_value/src/num_serializer.dart';
import 'package:built_value/src/regexp_serializer.dart';
import 'package:built_value/src/string_serializer.dart';
import 'package:built_value/src/uri_serializer.dart';
import 'package:built_value/standard_json_plugin.dart';
import 'package:datastore/datastore.dart';
import 'package:dent/account.dart';
import 'package:dent/business.dart';
import 'package:dent/content.dart';
import 'package:dent/core.dart';
import 'package:dent/legal.dart';
import 'package:dent/world.dart';

part 'datastore_serializers.g.dart';

final datastoreSerializers = (SerializersBuilder()
      ..merge(_serializers)
      ..addPlugin(StandardJsonPlugin(discriminator: '@type'))
      ..add(BigIntSerializer())
      ..add(BoolSerializer())
      ..add(BuiltListSerializer())
      ..add(BuiltListMultimapSerializer())
      ..add(BuiltMapSerializer())
      ..add(BuiltSetSerializer())
      ..add(BuiltSetMultimapSerializer())
      ..add(Iso8601DateTimeSerializer())
      ..add(DurationSerializer())
      ..add(IntSerializer())
      ..add(Int64Serializer())
      ..add(DoubleSerializer())
      ..add(JsonObjectSerializer())
      ..add(NumSerializer())
      ..add(RegExpSerializer())
      ..add(StringSerializer())
      ..add(UriSerializer())
      ..add(_DocumentSerializer())
      ..add(Date.serializer)
      ..add(EmailAddress.serializer)
      ..add(PhoneNumber.serializer)
      ..add(Money.serializer)
      ..add(Text.serializer)
      ..addBuilderFactory(const FullType(BuiltList, [FullType.object]),
          () => ListBuilder<Object>())
      ..addBuilderFactory(
          const FullType(BuiltListMultimap, [FullType.object, FullType.object]),
          () => ListMultimapBuilder<Object, Object>())
      ..addBuilderFactory(
          const FullType(BuiltMap, [FullType.object, FullType.object]),
          () => MapBuilder<Object, Object>())
      ..addBuilderFactory(const FullType(BuiltSet, [FullType.object]),
          () => SetBuilder<Object>())
      ..addBuilderFactory(
          const FullType(BuiltSetMultimap, [FullType.object, FullType.object]),
          () => SetMultimapBuilder<Object, Object>()))
    .build();

// Changed this? Run: './tool/build.sh'
@SerializersFor([
  // Account
  Account,
  Person,
  PersonName,
  Organization,

  // Business
  Product,
  ShoppingCart,
  ShoppingCartItem,
  ShoppingTransaction,

  // Content
  Post,

  // Legal
  Agreement,

  // World
  Place,
])
final Serializers _serializers = _$_serializers;

class _DocumentSerializer extends PrimitiveSerializer<Document> {
  _DocumentSerializer();

  @override
  Iterable<Type> get types => const [Document];

  @override
  String get wireName => 'document';

  @override
  Document deserialize(Serializers serializers, Object serialized,
      {FullType specifiedType = FullType.unspecified}) {
    if (serialized == null) {
      return null;
    }
    return serialized as Document;
  }

  @override
  Document serialize(Serializers serializers, Document object,
      {FullType specifiedType = FullType.unspecified}) {
    return object;
  }
}

==> dent-0.2.0.tar.gz: lib/src/core/datastore_serializers.dart <==
import 'package:built_collection/built_collection.dart';
import 'package:built_value/iso_8601_date_time_serializer.dart';
import 'package:built_value/serializer.dart';
import 'package:built_value/src/big_int_serializer.dart';
import 'package:built_value/src/bool_serializer.dart';
import 'package:built_value/src/built_list_multimap_serializer.dart';
import 'package:built_value/src/built_list_serializer.dart';
import 'package:built_value/src/built_map_serializer.dart';
import 'package:built_value/src/built_set_multimap_serializer.dart';
import 'package:built_value/src/built_set_serializer.dart';
import 'package:built_value/src/double_serializer.dart';
import 'package:built_value/src/duration_serializer.dart';
import 'package:built_value/src/int64_serializer.dart';
import 'package:built_value/src/int_serializer.dart';
import 'package:built_value/src/json_object_serializer.dart';
import 'package:built_value/src/num_serializer.dart';
import 'package:built_value/src/regexp_serializer.dart';
import 'package:built_value/src/string_serializer.dart';
import 'package:built_value/src/uri_serializer.dart';
import 'package:built_value/standard_json_plugin.dart';
import 'package:database/database.dart';
import 'package:dent/account.dart';
import 'package:dent/business.dart';
import 'package:dent/content.dart';
import 'package:dent/core.dart';
import 'package:dent/legal.dart';
import 'package:dent/world.dart';

part 'datastore_serializers.g.dart';

final datastoreSerializers = (SerializersBuilder()
      ..merge(_serializers)
      ..addPlugin(StandardJsonPlugin(discriminator: '@type'))
      ..add(BigIntSerializer())
      ..add(BoolSerializer())
      ..add(BuiltListSerializer())
      ..add(BuiltListMultimapSerializer())
      ..add(BuiltMapSerializer())
      ..add(BuiltSetSerializer())
      ..add(BuiltSetMultimapSerializer())
      ..add(Iso8601DateTimeSerializer())
      ..add(DurationSerializer())
      ..add(IntSerializer())
      ..add(Int64Serializer())
      ..add(DoubleSerializer())
      ..add(JsonObjectSerializer())
      ..add(NumSerializer())
      ..add(RegExpSerializer())
      ..add(StringSerializer())
      ..add(UriSerializer())
      ..add(_DocumentSerializer())
      ..add(_DateSerializer())
      ..add(EmailAddress.serializer)
      ..add(PhoneNumber.serializer)
      ..add(Money.serializer)
      ..add(Text.serializer)
      ..addBuilderFactory(const FullType(BuiltList, [FullType.object]),
          () => ListBuilder<Object>())
      ..addBuilderFactory(
          const FullType(BuiltListMultimap, [FullType.object, FullType.object]),
          () => ListMultimapBuilder<Object, Object>())
      ..addBuilderFactory(
          const FullType(BuiltMap, [FullType.object, FullType.object]),
          () => MapBuilder<Object, Object>())
      ..addBuilderFactory(const FullType(BuiltSet, [FullType.object]),
          () => SetBuilder<Object>())
      ..addBuilderFactory(
          const FullType(BuiltSetMultimap, [FullType.object, FullType.object]),
          () => SetMultimapBuilder<Object, Object>()))
    .build();

// Changed this? Run: './tool/build.sh'
@SerializersFor([
  // Account
  Account,
  Person,
  PersonName,
  Organization,

  // Business
  Product,
  ShoppingCart,
  ShoppingCartItem,
  ShoppingTransaction,

  // Content
  Post,

  // Legal
  Agreement,

  // World
  Place,
])
final Serializers _serializers = _$_serializers;

class _DocumentSerializer extends PrimitiveSerializer<Document> {
  _DocumentSerializer();

  @override
  Iterable<Type> get types => const [Document];

  @override
  String get wireName => 'document';

  @override
  Document deserialize(Serializers serializers, Object serialized,
      {FullType specifiedType = FullType.unspecified}) {
    if (serialized == null) {
      return null;
    }
    return serialized as Document;
  }

  @override
  Document serialize(Serializers serializers, Document object,
      {FullType specifiedType = FullType.unspecified}) {
    return object;
  }
}

class _DateSerializer implements PrimitiveSerializer<Date> {
  const _DateSerializer();

  @override
  Iterable<Type> get types => const [Date];

  @override
  String get wireName => 'phone_number';

  @override
  Date deserialize(Serializers serializers, Object serialized,
      {FullType specifiedType = FullType.unspecified}) {
    if (serialized is String) {
      return Date.parse(serialized);
    } else {
      throw ArgumentError.value(serialized);
    }
  }

  @override
  Object serialize(Serializers serializers, Date object,
      {FullType specifiedType = FullType.unspecified}) {
    return '${object.year}-${object.month}-${object.day}';
  }
}
